@@ -500,7 +500,6 @@ def build_app(
     auth.setup_auth(app)
 
     with app.app_context():
-
         from .dash_application import views as dash_views
 
         app = dash_views.add_dash(app)
@@ -679,8 +678,18 @@ def show(data=None, data_loader=None, name=None, context_vars=None, **options):
     :param github_fork: If true, this will display a "Fork me on GitHub" ribbon in the upper right-hand corner of the
                         app
     :type github_fork: bool, optional
-    :param hide_drop_rows: If true, this will hide the "Drop Rows" buton from users
+    :param hide_drop_rows: If true, this will hide the "Drop Rows" button from users
     :type hide_drop_rows: bool, optional
+    :param hide_header_editor: If true, this will hide the header editor when editing cells
+    :type hide_header_editor: bool, optional
+    :param column_edit_options: The options to allow on the front-end when editing a cell for the columns specified
+    :type column_edit_options: dict, optional
+    :param auto_hide_empty_columns: if True, then auto-hide any columns on the front-end that are comprised entirely of
+                                    NaN values
+    :type auto_hide_empty_columns: boolean, optional
+    :param highlight_filter: if True, then highlight rows on the frontend which will be filtered when applying a filter
+                             rather than hiding them from the dataframe
+    :type highlight_filter: boolean, optional
 
     :Example:
 
@@ -757,6 +766,10 @@ def show(data=None, data_loader=None, name=None, context_vars=None, **options):
             is_proxy=JUPYTER_SERVER_PROXY,
             app_root=final_app_root,
             hide_shutdown=final_options.get("hide_shutdown"),
+            column_edit_options=final_options.get("column_edit_options"),
+            auto_hide_empty_columns=final_options.get("auto_hide_empty_columns"),
+            highlight_filter=final_options.get("highlight_filter"),
+            hide_header_editor=final_options.get("hide_header_editor"),
         )
         instance.started_with_open_browser = final_options["open_browser"]
         is_active = not running_with_flask_debug() and is_up(app_url)
