@@ -1,14 +1,14 @@
 import plotly.graph_objs as go
 from dash.dependencies import Input, Output, State
-from dash.exceptions import PreventUpdate
 
 from dtale.charts.utils import MAX_GROUPS
+from dtale.dash_application.exceptions import DtalePreventUpdate
 
 
 def init_callbacks(dash_app):
     def lock_zoom(clicks, relayout_data, figure):
         if not clicks:
-            raise PreventUpdate
+            raise DtalePreventUpdate
         figure = go.Figure(figure)
         if relayout_data:
             figure.update_layout(scene_camera=relayout_data["scene.camera"])
