@@ -1,10 +1,11 @@
 import dash_bootstrap_components as dbc
+
 from dash.dependencies import Input, Output, State
-from dash.exceptions import PreventUpdate
 
 from dtale.charts.utils import ANIMATION_CHARTS, ANIMATE_BY_CHARTS, ZAXIS_CHARTS
 from dtale.dash_application import dcc, html
 from dtale.dash_application.charts import build_chart, valid_chart
+from dtale.dash_application.exceptions import DtalePreventUpdate
 from dtale.dash_application.layout.utils import build_hoverable
 from dtale.utils import dict_merge, is_app_root_defined, flatten_lists, make_list
 from dtale.translations import text
@@ -180,7 +181,7 @@ def init_callbacks(dash_app):
 
         if delete_idx is None:
             if save_clicks == prev_save_clicks:
-                raise PreventUpdate
+                raise DtalePreventUpdate
 
             config = dict_merge(
                 inputs,
@@ -192,7 +193,7 @@ def init_callbacks(dash_app):
             )
 
             if not valid_chart(**config):
-                raise PreventUpdate
+                raise DtalePreventUpdate
 
             for index, saved_config in enumerate(updated_configs):
                 if saved_config is None:
@@ -205,12 +206,12 @@ def init_callbacks(dash_app):
 
     def load_saved_chart(_ts, config, prev_config):
         if config == prev_config:
-            raise PreventUpdate
+            raise DtalePreventUpdate
         if config is None:
             return dict(display="none"), None, None, None
         if is_app_root_defined(dash_app.server.config.get("APPLICATION_ROOT")):
             config["app_root"] = dash_app.server.config["APPLICATION_ROOT"]
-        charts, _, _ = build_chart(**config)
+        charts, _, _, _ = build_chart(**config)
         return dict(display="block"), charts, config, build_saved_header(config)
 
     dash_app.callback(
