@@ -3,11 +3,12 @@ from logging import getLogger
 
 import dash
 from dash.dependencies import Input, Output, State
-from dash.exceptions import PreventUpdate
+from six import PY3
 
 from dtale.dash_application import dcc, html
 import dtale.dash_application.custom_geojson as custom_geojson
 import dtale.dash_application.drilldown_modal as drilldown_modal
+from dtale.dash_application.exceptions import DtalePreventUpdate
 import dtale.dash_application.extended_aggregations as extended_aggregations
 import dtale.dash_application.saved_charts as saved_charts
 import dtale.dash_application.lock_zoom as lock_zoom
@@ -49,6 +50,7 @@ from dtale.dash_application.layout.layout import (
     get_group_types,
     show_input_handler,
     show_yaxis_ranges,
+    bootstrap_checkbox_prop,
 )
 from dtale.dash_application.layout.utils import show_style
 from dtale.dash_application.utils import get_data_id
@@ -130,6 +132,18 @@ def add_dash(server):
 
     init_callbacks(dash_app)
 
+    def _handle_error(error):
+        """Replace the default handler with one that does not print anything"""
+        import dtale.app as dtale_app
+
+        if dtale_app.USE_COLAB:
+            raise ValueError(
+                "Currently executing in google colab which does not handle dash.PreventUpdate 204s"
+            )
+        return "", 204
+
+    dash_app.server.errorhandler(DtalePreventUpdate)(_handle_error)
+
     return dash_app.server
 
 
@@ -232,6 +246,7 @@ def init_callbacks(dash_app):
             Input("load-input", "value"),
             Input("load-type-dropdown", "value"),
             Input("cleaners-dropdown", "value"),
+            Input("dropna-checkbox", bootstrap_checkbox_prop()),
         ],
         [
             State("url", "pathname"),
@@ -259,6 +274,7 @@ def init_callbacks(dash_app):
         load,
         load_type,
         cleaners,
+        dropna,
         pathname,
         query,
         data_id,
@@ -291,6 +307,7 @@ def init_callbacks(dash_app):
             load=load,
             load_type=load_type,
             cleaners=make_list(cleaners),
+            dropna=True if dropna is None else dropna,
         )
         options = build_input_options(
             global_state.get_data(data_id),
@@ -369,7 +386,7 @@ def init_callbacks(dash_app):
     )
     def update_data_selection(data_id, input_data):
         if data_id == input_data["data_id"]:
-            raise PreventUpdate
+            raise DtalePreventUpdate
         return None, None, None, None, None, None
 
     @dash_app.callback(
@@ -403,6 +420,7 @@ def init_callbacks(dash_app):
             Input("map-mapbox-style-dropdown", "value"),
             Input("map-proj-dropdown", "value"),
             Input("map-group-dropdown", "value"),
+            Input("map-dropna-checkbox", bootstrap_checkbox_prop()),
             Input("geojson-dropdown", "value"),
             Input("featureidkey-dropdown", "value"),
         ],
@@ -419,6 +437,7 @@ def init_callbacks(dash_app):
         style,
         proj,
         group,
+        dropna,
         geojson,
         featureidkey,
         data_id,
@@ -426,14 +445,23 @@ def init_callbacks(dash_app):
         map_type = map_type or "choropleth"
         if map_type == "choropleth":
             map_data = dict(
-                map_type=map_type, loc_mode=loc_mode, loc=loc, map_val=map_val
+                map_type=map_type,
+                loc_mode=loc_mode,
+                loc=loc,
+                map_val=map_val,
+                map_dropna=dropna,
             )
             if loc_mode == "geojson-id":
                 map_data["geojson"] = geojson
                 map_data["featureidkey"] = featureidkey
         elif map_type == "mapbox":
             map_data = dict(
-                map_type=map_type, lat=lat, lon=lon, map_val=map_val, mapbox_style=style
+                map_type=map_type,
+                lat=lat,
+                lon=lon,
+                map_val=map_val,
+                mapbox_style=style,
+                map_dropna=dropna,
             )
         else:
             map_data = dict(
@@ -443,6 +471,7 @@ def init_callbacks(dash_app):
                 map_val=map_val,
                 scope=scope,
                 proj=proj,
+                map_dropna=dropna,
             )
 
         if group is not None:
@@ -517,6 +546,7 @@ def init_callbacks(dash_app):
             Input("candlestick-high-dropdown", "value"),
             Input("candlestick-low-dropdown", "value"),
             Input("candlestick-group-dropdown", "value"),
+            Input("candlestick-dropna-checkbox", bootstrap_checkbox_prop()),
         ],
         [State("data-tabs", "value")],
     )
@@ -527,6 +557,7 @@ def init_callbacks(dash_app):
         cs_high,
         cs_low,
         group,
+        dropna,
         data_id,
     ):
         cs_data = dict(
@@ -535,6 +566,7 @@ def init_callbacks(dash_app):
             cs_close=cs_close,
             cs_high=cs_high,
             cs_low=cs_low,
+            cs_dropna=dropna,
         )
         if group is not None:
             cs_data["cs_group"] = group
@@ -564,10 +596,11 @@ def init_callbacks(dash_app):
         )
 
     def label_value_callback(prop):
-        def _callback(selected_value, selected_label, group, data_id, **kwargs):
+        def _callback(selected_value, selected_label, group, dropna, data_id, **kwargs):
             label_value_data = {
                 "{}_value".format(prop): selected_value,
                 "{}_label".format(prop): selected_label,
+                "{}_dropna".format(prop): True if dropna is None else dropna,
             }
             if group is not None:
                 label_value_data["{}_group".format(prop)] = group
@@ -583,9 +616,16 @@ def init_callbacks(dash_app):
 
         return _callback
 
-    def funnel_callback(selected_value, selected_label, group, stacked, data_id):
+    def funnel_callback(
+        selected_value, selected_label, group, dropna, stacked, data_id
+    ):
         label_value_data, value_options, label_options = label_value_callback("funnel")(
-            selected_value, selected_label, group, data_id, funnel_stacked=stacked
+            selected_value,
+            selected_label,
+            group,
+            dropna,
+            data_id,
+            funnel_stacked=stacked,
         )
         return (
             label_value_data,
@@ -594,10 +634,10 @@ def init_callbacks(dash_app):
             show_style(len(make_list(group)) > 0),
         )
 
-    def clustergram_callback(selected_value, selected_label, group, data_id):
+    def clustergram_callback(selected_value, selected_label, group, dropna, data_id):
         label_value_data, value_options, label_options = label_value_callback(
             "clustergram"
-        )(selected_value, selected_label, group, data_id)
+        )(selected_value, selected_label, group, dropna, data_id)
         return (
             label_value_data,
             value_options,
@@ -618,6 +658,7 @@ def init_callbacks(dash_app):
             Input("pareto-sort-dropdown", "value"),
             Input("pareto-dir-dropdown", "value"),
             Input("pareto-group-dropdown", "value"),
+            Input("pareto-dropna-checkbox", bootstrap_checkbox_prop()),
         ],
         [State("data-tabs", "value")],
     )
@@ -628,6 +669,7 @@ def init_callbacks(dash_app):
         pareto_sort,
         pareto_dir,
         group,
+        dropna,
         data_id,
     ):
         pareto_data = dict(
@@ -636,6 +678,7 @@ def init_callbacks(dash_app):
             pareto_line=pareto_line,
             pareto_sort=pareto_sort,
             pareto_dir=pareto_dir,
+            pareto_dropna=True if dropna is None else dropna,
         )
         if group is not None:
             pareto_data["pareto_group"] = group
@@ -664,6 +707,7 @@ def init_callbacks(dash_app):
             Input("treemap-value-dropdown", "value"),
             Input("treemap-label-dropdown", "value"),
             Input("treemap-group-dropdown", "value"),
+            Input("treemap-dropna-checkbox", bootstrap_checkbox_prop()),
         ],
         [State("data-tabs", "value")],
     )(label_value_callback("treemap"))
@@ -679,6 +723,7 @@ def init_callbacks(dash_app):
             Input("funnel-value-dropdown", "value"),
             Input("funnel-label-dropdown", "value"),
             Input("funnel-group-dropdown", "value"),
+            Input("funnel-dropna-checkbox", bootstrap_checkbox_prop()),
             Input("funnel-stack-toggle", "on"),
         ],
         [State("data-tabs", "value")],
@@ -694,6 +739,7 @@ def init_callbacks(dash_app):
             Input("clustergram-value-dropdown", "value"),
             Input("clustergram-label-dropdown", "value"),
             Input("clustergram-group-dropdown", "value"),
+            Input("clustergram-dropna-checkbox", bootstrap_checkbox_prop()),
         ],
         [State("data-tabs", "value")],
     )(clustergram_callback)
@@ -715,6 +761,7 @@ def init_callbacks(dash_app):
             Output("animate-by-input", "style"),
             Output("animate-by-dropdown", "options"),
             Output("trendline-input", "style"),
+            Output("dropna-input", "style"),
         ],
         [Input("input-data", "modified_timestamp")],
         [State("input-data", "data"), State("url", "pathname")],
@@ -731,6 +778,7 @@ def init_callbacks(dash_app):
         y_single_style = {"display": "block" if show_input("y") else "none"}
         z_style = {"display": "block" if show_input("z") else "none"}
         group_style = {"display": "block" if show_input("group") else "none"}
+        dropna_style = {"display": "block" if PY3 and show_input("group") else "none"}
         rolling_style = {"display": "inherit" if agg == "rolling" else "none"}
         cpg_style = {"display": "block" if show_chart_per_group(**inputs) else "none"}
         cpy_style = {"display": "block" if show_chart_per_y(**inputs) else "none"}
@@ -757,6 +805,7 @@ def init_callbacks(dash_app):
             animate_by_style,
             animate_opts,
             trendline_style,
+            dropna_style,
         )
 
     @dash_app.callback(
@@ -851,6 +900,8 @@ def init_callbacks(dash_app):
             Output("agg-dropdown", "disabled"),
             Output("extended-aggregation-tooltip", "children"),
             Output("ext-agg-warning", "style"),
+            Output("export-all-chart-btn", "href"),
+            Output("export-all-chart-btn", "style"),
         ],
         # Since we use the data prop in an output,
         # we cannot get the initial data on load with the data prop.
@@ -931,12 +982,12 @@ def init_callbacks(dash_app):
             else {},
         )
         if not auto_load and load_clicks == prev_load_clicks:
-            raise PreventUpdate
+            raise DtalePreventUpdate
         if all_inputs == last_chart_inputs:
-            raise PreventUpdate
+            raise DtalePreventUpdate
         if is_app_root_defined(dash_app.server.config.get("APPLICATION_ROOT")):
             all_inputs["app_root"] = dash_app.server.config["APPLICATION_ROOT"]
-        charts, range_data, code = build_chart(**all_inputs)
+        charts, range_data, code, export_all_href = build_chart(**all_inputs)
         agg_disabled = len(ext_aggs) > 0
         ext_agg_tt = text("ext_agg_desc")
         ext_agg_warning = show_style(agg_disabled)
@@ -973,6 +1024,8 @@ def init_callbacks(dash_app):
             agg_disabled,
             ext_agg_tt,
             ext_agg_warning,
+            export_all_href,
+            dict(display="none" if export_all_href == "" else "block"),
         )
 
     def get_default_range(range_data, y, max=False):
@@ -1104,8 +1157,8 @@ def init_callbacks(dash_app):
             maxs = range_data.get("max", {})
             range_min = get_default_range(mins, final_cols)
             range_max = get_default_range(maxs, final_cols, max=True)
-        elif yaxis is None:
-            raise PreventUpdate
+        elif yaxis is None or range_data is None:
+            raise DtalePreventUpdate
         else:
             range_min, range_max = (
                 range_data[p].get(yaxis_name) for p in ["min", "max"]
@@ -1250,7 +1303,7 @@ def init_callbacks(dash_app):
         """
         dash_app.config.suppress_callback_exceptions = False
         if pathname is None:
-            raise PreventUpdate
+            raise DtalePreventUpdate
         params = chart_url_params(search)
         params["data_id"] = params.get("data_id") or get_data_id(pathname)
         df = global_state.get_data(params["data_id"])
